@@ -191,12 +191,31 @@ go_gtk_builder_load (char const *uifile,
 		gtk_builder_set_translation_domain (gui, domain);
 
 	if (strncmp (uifile, "res:", 4) == 0) {
+		const char *resname = uifile + 4;
 		size_t len;
-		gconstpointer data = go_rsm_lookup (uifile + 4, &len);
-		GsfInput *src = data
+		gconstpointer data;
+		GsfInput *src;
+		GBytes *bytes = NULL;
+
+		// First try go resources
+		data = go_rsm_lookup (resname, &len);
+
+		// Then try glib
+		if (!data) {
+			bytes = g_resources_lookup_data (resname, 0, NULL);
+			if (bytes) {
+				data = g_bytes_get_data (bytes, NULL);
+				len = g_bytes_get_size (bytes);
+			}
+		}
+
+		src = data
 			? gsf_input_memory_new (data, len, FALSE)
 			: NULL;
 		ok = apply_ui_from_file (gui, src, NULL, &error);
+
+		if (bytes)
+			g_bytes_unref (bytes);
 	} else if (strncmp (uifile, "data:", 5) == 0) {
 		const char *data = uifile + 5;
 		GsfInput *src = gsf_input_memory_new (data, strlen (data), FALSE);
@@ -1633,3 +1652,215 @@ go_gtk_widget_render_icon_pixbuf (GtkWidget   *widget,
 
 	return res;
 }
+
+static GtkCssProvider *css_provider;
+static GSList *css_provider_screens;
+
+static void
+cb_screen_changed (GtkWidget *widget)
+{
+	GdkScreen *screen = gtk_widget_get_screen (widget);
+
+	if (!screen || g_slist_find (css_provider_screens, screen))
+		return;
+
+	css_provider_screens = g_slist_prepend (css_provider_screens, screen);
+	gtk_style_context_add_provider_for_screen
+		(screen,
+		 GTK_STYLE_PROVIDER (css_provider),
+		 GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+}
+
+
+void
+_go_gtk_widget_add_css_provider (GtkWidget *w)
+{
+	g_return_if_fail (GTK_IS_WIDGET (w));
+
+	if (!css_provider) {
+		const char *data = _go_gtk_new_theming ()
+			? go_rsm_lookup ("go:gtk/goffice.css", NULL)
+			: go_rsm_lookup ("go:gtk/goffice-old.css", NULL);
+		css_provider = gtk_css_provider_new ();
+		gtk_css_provider_load_from_data (css_provider, data, -1, NULL);
+	}
+
+	g_signal_connect (w, "screen-changed",
+			  G_CALLBACK (cb_screen_changed), NULL);
+	cb_screen_changed (w);
+}
+
+gboolean
+_go_gtk_new_theming (void)
+{
+#if GTK_CHECK_VERSION(3,20,0)
+	return TRUE;
+#else
+	static int new_theming = -1;
+	if (new_theming == -1)
+		new_theming = (gtk_get_major_version() > 3 ||
+			       gtk_get_minor_version() >= 20);
+
+	return new_theming;
+#endif
+}
+
+// ---------------------------------------------------------------------------
+// Foreign drawing style code copied from foreigndrawing.c
+
+#if GTK_CHECK_VERSION(3,20,0)
+static void
+append_element (GtkWidgetPath *path,
+                const char    *selector)
+{
+	static const struct {
+		const char    *name;
+		GtkStateFlags  state_flag;
+	} pseudo_classes[] = {
+		{ "active",        GTK_STATE_FLAG_ACTIVE },
+		{ "hover",         GTK_STATE_FLAG_PRELIGHT },
+		{ "selected",      GTK_STATE_FLAG_SELECTED },
+		{ "disabled",      GTK_STATE_FLAG_INSENSITIVE },
+		{ "indeterminate", GTK_STATE_FLAG_INCONSISTENT },
+		{ "focus",         GTK_STATE_FLAG_FOCUSED },
+		{ "backdrop",      GTK_STATE_FLAG_BACKDROP },
+		{ "dir(ltr)",      GTK_STATE_FLAG_DIR_LTR },
+		{ "dir(rtl)",      GTK_STATE_FLAG_DIR_RTL },
+		{ "link",          GTK_STATE_FLAG_LINK },
+		{ "visited",       GTK_STATE_FLAG_VISITED },
+		{ "checked",       GTK_STATE_FLAG_CHECKED },
+		{ "drop(active)",  GTK_STATE_FLAG_DROP_ACTIVE }
+	};
+	const char *next;
+	char *name;
+	char type;
+	guint i;
+
+	next = strpbrk (selector, "#.:");
+	if (next == NULL)
+		next = selector + strlen (selector);
+
+	name = g_strndup (selector, next - selector);
+	if (g_ascii_isupper (selector[0]))
+	{
+		GType gtype;
+		gtype = g_type_from_name (name);
+		if (gtype == G_TYPE_INVALID)
+		{
+			g_critical ("Unknown type name `%s'", name);
+			g_free (name);
+			return;
+		}
+		gtk_widget_path_append_type (path, gtype);
+	}
+	else
+	{
+		/* Omit type, we're using name */
+		gtk_widget_path_append_type (path, G_TYPE_NONE);
+		gtk_widget_path_iter_set_object_name (path, -1, name);
+	}
+	g_free (name);
+
+	while (*next != '\0')
+	{
+		type = *next;
+		selector = next + 1;
+		next = strpbrk (selector, "#.:");
+		if (next == NULL)
+			next = selector + strlen (selector);
+		name = g_strndup (selector, next - selector);
+
+		switch (type)
+		{
+		case '#':
+			gtk_widget_path_iter_set_name (path, -1, name);
+			break;
+
+		case '.':
+			gtk_widget_path_iter_add_class (path, -1, name);
+			break;
+
+		case ':':
+			for (i = 0; i < G_N_ELEMENTS (pseudo_classes); i++)
+			{
+				if (g_str_equal (pseudo_classes[i].name, name))
+				{
+					gtk_widget_path_iter_set_state (path,
+									-1,
+									gtk_widget_path_iter_get_state (path, -1)
+									| pseudo_classes[i].state_flag);
+					break;
+				}
+			}
+			if (i == G_N_ELEMENTS (pseudo_classes))
+				g_critical ("Unknown pseudo-class :%s", name);
+			break;
+
+		default:
+			g_assert_not_reached ();
+			break;
+		}
+
+		g_free (name);
+	}
+}
+
+static GtkStyleContext *
+create_context_for_path (GtkWidgetPath   *path,
+                         GtkStyleContext *parent)
+{
+	GtkStyleContext *context;
+
+	context = gtk_style_context_new ();
+	gtk_style_context_set_path (context, path);
+	gtk_style_context_set_parent (context, parent);
+	/* Unfortunately, we have to explicitly set the state again here
+	 * for it to take effect
+	 */
+	gtk_style_context_set_state (context, gtk_widget_path_iter_get_state (path, -1));
+	gtk_widget_path_unref (path);
+
+	return context;
+}
+#endif
+
+/**
+ * go_style_context_from_selector:
+ * @parent: (allow-none): style context for container
+ * @selector: a css selector
+ *
+ * Returns: (transfer full): a new style context.
+ */
+GtkStyleContext *
+go_style_context_from_selector (GtkStyleContext *parent,
+				const char      *selector)
+{
+#if GTK_CHECK_VERSION(3,20,0)
+	GtkWidgetPath *path;
+
+	g_return_val_if_fail (selector != NULL, NULL);
+
+	path = parent
+		? gtk_widget_path_copy (gtk_style_context_get_path (parent))
+		: gtk_widget_path_new ();
+
+	append_element (path, selector);
+
+	return create_context_for_path (path, parent);
+#else
+	(void)parent;
+	g_return_val_if_fail (selector != NULL, NULL);
+	g_assert_not_reached ();
+	return NULL;
+#endif
+}
+
+// ---------------------------------------------------------------------------
+
+void
+_go_gtk_shutdown (void)
+{
+	g_clear_object (&css_provider);
+	g_slist_free (css_provider_screens);
+	css_provider_screens = NULL;
+}
