@@ -1051,8 +1051,7 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 	double zmax, rmax = 0., x_left, y_bottom, x_right, y_top;
 	double x_margin_min, x_margin_max, y_margin_min, y_margin_max, margin;
 	double xerrmin, xerrmax, yerrmin, yerrmax;
-	double x_baseline, y_baseline;
-	gboolean show_marks, show_lines, show_fill, show_negatives, in_3d, size_as_area = TRUE;
+	gboolean show_marks, show_lines, show_fill, show_negatives, size_as_area = TRUE;
 	gboolean is_map = GOG_IS_XY_COLOR_PLOT (model), hide_outliers = TRUE;
 	GogObjectRole const *lbl_role = NULL;
 	GogAxisColorMap const *color_map = NULL;
@@ -1100,9 +1099,6 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 	y_bottom = gog_axis_map_to_view (y_map, y_bottom);
 	y_top = gog_axis_map_to_view (y_map, y_top);
 
-	x_baseline = gog_axis_map_get_baseline (x_map);
-	y_baseline = gog_axis_map_get_baseline (y_map);
-
 	gog_renderer_push_clip_rectangle (view->renderer, view->allocation.x, view->allocation.y,
 					  view->allocation.w, view->allocation.h);
 
@@ -1140,7 +1136,7 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 				path = gog_chart_map_make_path (chart_map, x_vals, y_vals,
 								n, series->base.interpolation,
 								series->base.interpolation_skip_invalid,
-								&series->clamped_derivs);
+								(gpointer)&series->clamped_derivs);
 
 			next_path = NULL;
 
@@ -1171,7 +1167,7 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 							(chart_map, next_x_vals, next_y_vals,
 							 next_n_points, next_series->base.interpolation,
 							 series->base.interpolation_skip_invalid,
-							 &series->clamped_derivs);
+							 (gpointer)&series->clamped_derivs);
 
 					}
 				}
@@ -1289,7 +1285,7 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 			rmax = MIN (view->residual.w, view->residual.h) / BUBBLE_MAX_RADIUS_RATIO
 						* GOG_BUBBLE_PLOT (view->model)->bubble_scale;
 			size_as_area = GOG_BUBBLE_PLOT (view->model)->size_as_area;
-			in_3d = GOG_BUBBLE_PLOT (view->model)->in_3d;
+			// in_3d = GOG_BUBBLE_PLOT (view->model)->in_3d;
 			if (show_negatives) {
 				zmin = fabs (zmin);
 				if (zmin > zmax) zmax = zmin;
@@ -1527,7 +1523,8 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 				if (zmin > zmax) zmax = zmin;
 			}
 			n = gog_series_get_xyz_data (GOG_SERIES (series), &x_vals, &y_vals, &z_vals);
-		}
+		} else if (GOG_IS_XY_COLOR_PLOT (model))
+			n = gog_series_get_xyz_data (GOG_SERIES (series), &x_vals, &y_vals, &z_vals);
 		else
 			n = gog_series_get_xy_data (GOG_SERIES (series), &x_vals, &y_vals);
 		if (n < 1) {
@@ -1566,7 +1563,7 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 				alloc.x = gog_axis_map_to_view (x_map, x);
 				alloc.y = gog_axis_map_to_view (y_map, y);
 				Elt = gog_series_labels_vector_get_element (lbls, i - 1);
-				if (Elt->point) {
+				if (Elt && Elt->point) {
 					g_object_get (Elt->point, "offset", &cur_offset, NULL);
 					cur_position = gog_data_label_get_position (GOG_DATA_LABEL (Elt->point));
 				} else {
